@@ -1,7 +1,7 @@
 from smart_open import smart_open_lib
 from requests.exceptions import HTTPError
 
-from .common import PurePath, _SkeletonPath
+from .common import PurePath, Path, _SkeletonPath
 from .uri import _UriFlavour
 
 
@@ -12,11 +12,13 @@ class _HttpFlavour(_UriFlavour):
 _http_flavour = _HttpFlavour()
 
 
+@PurePath.register
 class PureHttpPath(PurePath):
     _flavour = _http_flavour
     __slots__ = ()
 
 
+@Path.register
 class HttpPath(_SkeletonPath, PureHttpPath):
     __slots__ = ()
 
