@@ -1,6 +1,6 @@
 import pathlib
 
-from paaaaath.common import Path, PurePath
+from .common import Path, PurePath
 
 
 class PurePosixPath(PurePath, pathlib.PurePosixPath):
